Tint.XYZ (Tint v1.1.0) View Source

A color in the XYZ (CIE 1931) colorspace.

Link to this section Summary

Functions

Builds a new XYZ color using the lightness, a and b color channels.

Link to this section Types

Specs

t() :: %Tint.XYZ{x: float(), y: float(), z: float()}

Link to this section Functions

Specs

new(number() | String.t(), number() | String.t(), number() | String.t()) :: t()

Builds a new XYZ color using the lightness, a and b color channels.