Tint.XYZ (Tint v1.1.0) View Source
A color in the XYZ (CIE 1931) colorspace.
Link to this section Summary
Functions
Builds a new XYZ color using the lightness, a and b color channels.
Link to this section Types
Specs
Link to this section Functions
Specs
Builds a new XYZ color using the lightness, a and b color channels.